from enum import IntEnum


class YouthStudyEnum(IntEnum):
    """
    SLEEP_TIME: 睡眠时间\n
    ITERATIONS: 迭代次数\n
    """
    SLEEP_TIME = 180
    MAX_ITERATIONS = 200
